#include <windows.h>
#include <dirent.h>
#include <iostream>
#include <list>
#include <string>
#include <cstdlib>

using namespace std;

struct Plugin
{
    typedef double (*Operation)(double, double);

    char symbol;
    Operation operation;
};

list<Plugin> plugins;

typedef char (*GetSymbolFunction)();

void loadPlugins()
{
    DIR *dirp = opendir("plugins");

    if (dirp) {
        while(true) {
            dirent *dp = readdir(dirp);

            if (dp == 0) {
                break;
            }

            string name = string("plugins\\") + dp->d_name;
            size_t size = name.size();

            if (size >= 4 && name.substr(size - 4) != ".dll") {
                continue;
            }

            HMODULE library = LoadLibrary(name.c_str());

            if (library) {
                GetSymbolFunction getSymbolFunction = (GetSymbolFunction) GetProcAddress(library, "getSymbol");
                Plugin::Operation operation = (Plugin::Operation) GetProcAddress(library, "operation");

                if (getSymbolFunction && operation) {
                    Plugin plugin;

                    plugin.symbol = getSymbolFunction();
                    plugin.operation = operation;
                    plugins.push_back(plugin);
                } else {
                    FreeLibrary(library);
                }
            }
        };

        closedir(dirp);
    }
}

int main()
{
    double arg1, arg2;
    char operation;

    loadPlugins();

    while (true) {
        list<Plugin>::const_iterator i;

        cin >> arg1 >> operation >> arg2;

        for (i = plugins.begin(); i != plugins.end(); ++i) {
            if ((*i).symbol == operation) {
                break;
            }
        }

        if (i == plugins.end()) {
            break;
        }

        cout << (*i).operation(arg1, arg2) << endl;
    }

    return EXIT_SUCCESS;
}
